@@ -1,11 +1,15 @@
-from pytest import mark
 from collections import namedtuple
+from functools import partial
+
+from pytest import mark
 
 from characteristic import Attribute
 from characteristic import attributes
 
 from fields import __base__
 from fields import Fields
+from fields import SlotsFields
+from fields import Tuple
 
 
 @attributes(["a", "b", Attribute("c", default_value="abc")])
@@ -16,6 +20,15 @@ class characteristic_class(object):
 class fields_class(Fields.a.b.c["abc"]):
     pass
 
+
+class slots_class(SlotsFields.a.b.c["abc"]):
+    pass
+
+
+class tuple_class(Tuple.a.b.c["abc"]):
+    pass
+
+
 def make_super_dumb_class():
     class super_dumb_class(__base__):
         def __init__(self, a, b, c="abc"):
@@ -36,24 +49,28 @@ namedtuple_class = namedtuple("namedtuple_class", ["a", "b", "c"])
 
 
 def test_characteristic(benchmark):
-    with benchmark:
-        assert characteristic_class(a=1, b=2, c=1)
+    assert benchmark(partial(characteristic_class, a=1, b=2, c=1))
 
 
 def test_fields(benchmark):
-    with benchmark:
-        assert fields_class(a=1, b=2, c=1)
+    assert benchmark(partial(fields_class, a=1, b=2, c=1))
+
+
+def test_slots_fields(benchmark):
+    assert benchmark(partial(slots_class, a=1, b=2, c=1))
 
 
 def test_super_dumb(benchmark):
-    with benchmark:
-        assert super_dumb_class(a=1, b=2, c=1)
+    assert benchmark(partial(super_dumb_class, a=1, b=2, c=1))
 
 
 def test_dumb(benchmark):
-    with benchmark:
-        assert dumb_class(a=1, b=2, c=1)
+    assert benchmark(partial(dumb_class, a=1, b=2, c=1))
+
+
+def test_tuple(benchmark):
+    assert benchmark(partial(tuple_class, a=1, b=2, c=1))
+
 
 def test_namedtuple(benchmark):
-    with benchmark:
-        assert namedtuple_class(a=1, b=2, c=1)
+    assert benchmark(partial(namedtuple_class, a=1, b=2, c=1))
